@@ -1,5 +1,4 @@
-competition <-
-function(t, y, parameters){
+competition <- function(t, y, parameters){
   x <- y[1]
   y <- y[2]
   r1      <- parameters[1]
@@ -8,8 +7,8 @@ function(t, y, parameters){
   r2      <- parameters[4]
   K2      <- parameters[5]
   alpha21 <- parameters[6]
-  dy    <- rep(0, 2)
+  dy    <- numeric(2)
   dy[1] <- r1*x*(K1 - x - alpha12*y)/K1
   dy[2] <- r2*y*(K2 - y - alpha21*x)/K2
   list(dy)
-}
+}
\ No newline at end of file
