@@ -1,6 +1,5 @@
-exponential <-
-function(t, y, parameters){
+exponential <- function(t, y, parameters){
   beta <- parameters[1]
   dy <- beta*y
   list(dy)
-}
+}
\ No newline at end of file
